@@ -9,6 +9,16 @@ use investments::core::EmptyResult;
 fn generate_regression_tests() {
     let mut t = Tests::new();
 
+    // cli
+    t.add("Help", "--help");
+    for command in [
+        "sync", "show", "rebalance", "cash", "buy", "sell",
+        "analyse", "simulate-sell", "tax-statement", "cash-flow",
+        "deposits", "metrics", "completion",
+    ] {
+        t.add(&format!("Help {}", command), &format!("{} --help", command));
+    }
+
     // deposits
     t.add("Deposits", "deposits");
     t.add("Deposits cron mode", "deposits --cron --date 01.01.2100");
@@ -44,7 +54,13 @@ fn generate_regression_tests() {
     t.add("Open SPB dividends tax statement", "tax-statement open-dividends-spb").config("other");
     t.add("Tinkoff complex tax statement", "tax-statement tinkoff-complex").config("other");
     t.add("Tinkoff complex full tax statement", "tax-statement tinkoff-complex-full").config("other");
-    t.tax_statement("Tinkoff complex full", 2020).config("other"); // Dividends from several jurisdictions
+
+    // Not all calculations are seen in tax-statement output. For example, dividend jurisdiction
+    // appear only in the tax statement, so it worth to test also third party statements here.
+    t.tax_statement("IB complex", 2020).config("other");
+    t.tax_statement("Open dividends MOEX", 2021).config("other");
+    t.tax_statement("Open dividends SPB", 2021).config("other");
+    t.tax_statement("Tinkoff complex full", 2020).config("other");
 
     // cash-flow
     t.add("IB margin RUB cash flow", "cash-flow ib-margin-rub").config("other");
@@ -61,8 +77,9 @@ fn generate_regression_tests() {
     t.add("Tinkoff complex cash flow", "cash-flow tinkoff-complex").config("other");
     t.add("Tinkoff complex full cash flow", "cash-flow tinkoff-complex-full").config("other");
 
-    // metrics
-    t.add("Metrics", "metrics $OUT_PATH/metrics");
+    // other
+    t.add("Metrics", "metrics $OUT_PATH/metrics.prom");
+    t.add("Completion", "completion $OUT_PATH/completion.bash");
 
     let accounts = &[
         ("IB", Some(2018)),
@@ -76,7 +93,7 @@ fn generate_regression_tests() {
         ("Kate", None),
         ("Kate IIA", None),
     ];
-    let last_tax_year = 2021;
+    let last_tax_year = 2021; // FIXME(konishchev): Bump after statements update
 
     for &(name, start_tax_year) in accounts {
         let id = &name_to_id(name);
